==> crm-commom-vo-1.0.1.release.jar: com/biz/crm/nebular/mdm/product/resp/MdmProductAdviseRespVo.java <==
package com.biz.crm.nebular.mdm.product.resp;

import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmExtVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 商品信息可控规则响应
 *
 * @author zxw
 * @date 2020-10-09 11:14
 **/
@Data
@ApiModel(value = "商品信息可控规则响应")
@SaturnEntity(name = "MdmProductAdviseRespVo", description = "商品信息可控规则响应")
public class MdmProductAdviseRespVo extends CrmExtVo {
    @ApiModelProperty("商品编码")
    private String productCode;

    @ApiModelProperty("商品名称")
    private String productName;

    @ApiModelProperty("产品层级编码")
    private String productLevelCode;

    @ApiModelProperty("产品层级")
    private String productLevelName;

    @ApiModelProperty("商品类型(数据字典)")
    private String productType;

    @ApiModelProperty("商品类型")
    @CrmDict( typeCode = "product_type", dictCodeField = "productType")
    private String productTypeName;

    @ApiModelProperty("销售单位(字典编码)")
    private String saleUnit;

    @ApiModelProperty("销售单位")
    @CrmDict( typeCode = "product_sale_unit", dictCodeField = "saleUnit")
    private String saleUnitName;

    @ApiModelProperty("规格")
    @SaturnColumn(description = "规格")
    private String spec;

    @ApiModelProperty("基本单位(字典编码)")
    private String baseUnit;

    @ApiModelProperty("基本单位")
    @CrmDict( typeCode = "product_base_unit", dictCodeField = "baseUnit")
    private String baseUnitName;

    @ApiModelProperty("开始日期")
    private Long beginDate;

    @ApiModelProperty("开始时间")
    private String beginDateSecond;

    @ApiModelProperty("结束日期")
    private Long endDate;

    @ApiModelProperty("结束时间")
    private String endDateSecond;

    @ApiModelProperty("上下架状态(数据字典)")
    private String isShelf;

    @ApiModelProperty("上下架状态")
    @CrmDict( typeCode = "is_shelf", dictCodeField = "isShelf")
    private String isShelfName;

    @ApiModelProperty("条形码")
    @SaturnColumn(description = "条形码")
    private String barCode;

    @SaturnColumn(description = "物料信息")
    private String materialList;

    @ApiModelProperty("图片信息")
    private String pictureList;

    @ApiModelProperty("视频信息")
    private String videoList;

    @ApiModelProperty("富文本信息")
    private String introductionVo;
}

==> crm-commom-vo-1.2.9.release.jar: com/biz/crm/nebular/mdm/product/resp/MdmProductAdviseRespVo.java <==
package com.biz.crm.nebular.mdm.product.resp;

import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmExtVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 商品信息可控规则响应
 *
 * @author zxw
 * @date 2020-10-09 11:14
 **/
@Data
@ApiModel(value = "商品信息可控规则响应")
@SaturnEntity(name = "MdmProductAdviseRespVo", description = "商品信息可控规则响应")
public class MdmProductAdviseRespVo extends CrmExtVo {
    @ApiModelProperty("商品编码")
    @SaturnColumn(description = "商品编码")
    private String productCode;

    @ApiModelProperty("商品名称")
    @SaturnColumn(description = "商品名称")
    private String productName;

    @ApiModelProperty("产品层级编码")
    @SaturnColumn(description = "产品层级编码")
    private String productLevelCode;

    @ApiModelProperty("产品层级")
    @SaturnColumn(description = "产品层级")
    private String productLevelName;

    @ApiModelProperty("商品类型(数据字典)")
    @SaturnColumn(description = "商品类型(数据字典)")
    private String productType;

    @ApiModelProperty("商品类型")
    @SaturnColumn(description = "商品类型")
    @CrmDict( typeCode = "product_type", dictCodeField = "productType")
    private String productTypeName;

    @ApiModelProperty("销售单位(字典编码)")
    @SaturnColumn(description = "销售单位(字典编码)")
    private String saleUnit;

    @ApiModelProperty("销售单位")
    @SaturnColumn(description = "销售单位")
    @CrmDict( typeCode = "product_sale_unit", dictCodeField = "saleUnit")
    private String saleUnitName;

    @ApiModelProperty("规格")
    @SaturnColumn(description = "规格")
    private String spec;

    @ApiModelProperty("基本单位(字典编码)")
    @SaturnColumn(description = "基本单位(字典编码)")
    private String baseUnit;

    @ApiModelProperty("基本单位")
    @SaturnColumn(description = "基本单位")
    @CrmDict( typeCode = "product_base_unit", dictCodeField = "baseUnit")
    private String baseUnitName;

    @ApiModelProperty("开始日期")
    @SaturnColumn(description = "开始日期")
    private Long beginDate;

    @ApiModelProperty("开始时间")
    @SaturnColumn(description = "开始时间")
    private String beginDateSecond;

    @ApiModelProperty("结束日期")
    @SaturnColumn(description = "结束日期")
    private Long endDate;

    @ApiModelProperty("结束时间")
    @SaturnColumn(description = "结束时间")
    private String endDateSecond;

    @ApiModelProperty("上下架状态(数据字典)")
    @SaturnColumn(description = "上下架状态(数据字典)")
    private String isShelf;

    @ApiModelProperty("上下架状态")
    @SaturnColumn(description = "上下架状态")
    @CrmDict( typeCode = "is_shelf", dictCodeField = "isShelf")
    private String isShelfName;

    @ApiModelProperty("条形码")
    @SaturnColumn(description = "条形码")
    private String barCode;

    @SaturnColumn(description = "物料信息")
    private String materialList;

    @ApiModelProperty("图片信息")
    @SaturnColumn(description = "图片信息")
    private String pictureList;

    @ApiModelProperty("视频信息")
    @SaturnColumn(description = "视频信息")
    private String videoList;

    @ApiModelProperty("富文本信息")
    @SaturnColumn(description = "富文本信息")
    private String introductionVo;
}
